"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.clear = exports.remove = exports.get = exports.set = void 0;
function set(key, value, cache) {
    if (cache && typeof cache !== 'number') {
        throw new TypeError("Parameter 'cache' should be Number type.");
    }
    var convertedValue = (Array.isArray(value) || toString.call(value) === '[object Object]')
        ? JSON.stringify(value)
        : value;
    var formatted = {
        value: convertedValue,
        expiredAt: cache > 0
            ? new Date().getTime() + cache
            : null
    };
    localStorage.setItem(key, JSON.stringify(formatted));
    return null;
}
exports.set = set;
function get(key, parse) {
    var value = localStorage.getItem(key);
    if (value === null) {
        return null;
    }
    var parsed = JSON.parse(value);
    if (!(parsed.hasOwnProperty('value') && parsed.hasOwnProperty('expiredAt'))) {
        return value;
    }
    try {
        var parsedValue = parse
            ? JSON.parse(parsed.value)
            : parsed.value;
        if (parsed.expiredAt !== null) {
            var currTime = new Date().getTime();
            var expiredAt = parsed.expiredAt;
            if (currTime > expiredAt) {
                return remove(key);
            }
            return parsedValue;
        }
        return parsedValue;
    }
    catch (e) {
        return null;
    }
}
exports.get = get;
function remove(key) {
    localStorage.removeItem(key);
    return null;
}
exports.remove = remove;
function clear() {
    localStorage.clear();
    return null;
}
exports.clear = clear;
